diff --git a/shared/Mocks/Common/CustomStateDataFormat.cs b/shared/Mocks/Common/CustomStateDataFormat.cs
index 8a88afc676..2054996159 100644
--- a/shared/Mocks/Common/CustomStateDataFormat.cs
+++ b/shared/Mocks/Common/CustomStateDataFormat.cs
@@ -1,6 +1,6 @@
-#if TESTING
-using Microsoft.AspNet.Authentication;
-using Microsoft.AspNet.Http.Authentication;
+#if TESTING
+using Microsoft.AspNetCore.Authentication;
+using Microsoft.AspNetCore.Http.Authentication;
using Newtonsoft.Json;
namespace MusicStore.Mocks.Common
diff --git a/shared/Mocks/Facebook/FacebookMockBackChannelHttpHandler.cs b/shared/Mocks/Facebook/FacebookMockBackChannelHttpHandler.cs
index d82674562c..761e7bdea3 100644
--- a/shared/Mocks/Facebook/FacebookMockBackChannelHttpHandler.cs
+++ b/shared/Mocks/Facebook/FacebookMockBackChannelHttpHandler.cs
@@ -1,11 +1,11 @@
-#if TESTING
+#if TESTING
using System;
using System.Net;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
using MusicStore.Mocks.Common;
namespace MusicStore.Mocks.Facebook
diff --git a/shared/Mocks/Facebook/TestFacebookEvents.cs b/shared/Mocks/Facebook/TestFacebookEvents.cs
index af073da374..1c8a6deab1 100644
--- a/shared/Mocks/Facebook/TestFacebookEvents.cs
+++ b/shared/Mocks/Facebook/TestFacebookEvents.cs
@@ -1,12 +1,12 @@
-#if TESTING
+#if TESTING
using System;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authentication;
-using Microsoft.AspNet.Authentication.Facebook;
-using Microsoft.AspNet.Authentication.OAuth;
-using Microsoft.AspNet.Identity;
+using Microsoft.AspNetCore.Authentication;
+using Microsoft.AspNetCore.Authentication.Facebook;
+using Microsoft.AspNetCore.Authentication.OAuth;
+using Microsoft.AspNetCore.Identity;
using MusicStore.Mocks.Common;
namespace MusicStore.Mocks.Facebook
diff --git a/shared/Mocks/Google/GoogleMockBackChannelHttpHandler.cs b/shared/Mocks/Google/GoogleMockBackChannelHttpHandler.cs
index 282cc9a1a0..6b91ecae5a 100644
--- a/shared/Mocks/Google/GoogleMockBackChannelHttpHandler.cs
+++ b/shared/Mocks/Google/GoogleMockBackChannelHttpHandler.cs
@@ -1,12 +1,12 @@
-#if TESTING
+#if TESTING
using System;
using System.Net;
using System.Net.Http;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
namespace MusicStore.Mocks.Google
{
diff --git a/shared/Mocks/Google/TestGoogleEvents.cs b/shared/Mocks/Google/TestGoogleEvents.cs
index c7948b9d39..a39381cc45 100644
--- a/shared/Mocks/Google/TestGoogleEvents.cs
+++ b/shared/Mocks/Google/TestGoogleEvents.cs
@@ -1,12 +1,12 @@
-#if TESTING
+#if TESTING
using System;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authentication;
-using Microsoft.AspNet.Authentication.Google;
-using Microsoft.AspNet.Authentication.OAuth;
-using Microsoft.AspNet.Identity;
+using Microsoft.AspNetCore.Authentication;
+using Microsoft.AspNetCore.Authentication.Google;
+using Microsoft.AspNetCore.Authentication.OAuth;
+using Microsoft.AspNetCore.Identity;
using MusicStore.Mocks.Common;
namespace MusicStore.Mocks.Google
diff --git a/shared/Mocks/MicrosoftAccount/MicrosoftAccountMockBackChannelHandler.cs b/shared/Mocks/MicrosoftAccount/MicrosoftAccountMockBackChannelHandler.cs
index 0483b348e4..e778e8cb7a 100644
--- a/shared/Mocks/MicrosoftAccount/MicrosoftAccountMockBackChannelHandler.cs
+++ b/shared/Mocks/MicrosoftAccount/MicrosoftAccountMockBackChannelHandler.cs
@@ -1,12 +1,12 @@
-#if TESTING
+#if TESTING
using System;
using System.Net;
using System.Net.Http;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
namespace MusicStore.Mocks.MicrosoftAccount
{
diff --git a/shared/Mocks/MicrosoftAccount/TestMicrosoftAccountEvents.cs b/shared/Mocks/MicrosoftAccount/TestMicrosoftAccountEvents.cs
index 9471d25f1c..cfd24adf44 100644
--- a/shared/Mocks/MicrosoftAccount/TestMicrosoftAccountEvents.cs
+++ b/shared/Mocks/MicrosoftAccount/TestMicrosoftAccountEvents.cs
@@ -1,12 +1,12 @@
-#if TESTING
+#if TESTING
using System;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authentication;
-using Microsoft.AspNet.Authentication.MicrosoftAccount;
-using Microsoft.AspNet.Authentication.OAuth;
-using Microsoft.AspNet.Identity;
+using Microsoft.AspNetCore.Authentication;
+using Microsoft.AspNetCore.Authentication.MicrosoftAccount;
+using Microsoft.AspNetCore.Authentication.OAuth;
+using Microsoft.AspNetCore.Identity;
using MusicStore.Mocks.Common;
namespace MusicStore.Mocks.MicrosoftAccount
diff --git a/shared/Mocks/OpenIdConnect/CustomStringDataFormat.cs b/shared/Mocks/OpenIdConnect/CustomStringDataFormat.cs
index d06830f8c4..cea911f1d3 100644
--- a/shared/Mocks/OpenIdConnect/CustomStringDataFormat.cs
+++ b/shared/Mocks/OpenIdConnect/CustomStringDataFormat.cs
@@ -1,5 +1,5 @@
-#if TESTING
-using Microsoft.AspNet.Authentication;
+#if TESTING
+using Microsoft.AspNetCore.Authentication;
namespace MusicStore.Mocks.OpenIdConnect
{
diff --git a/shared/Mocks/OpenIdConnect/TestOpenIdConnectEvents.cs b/shared/Mocks/OpenIdConnect/TestOpenIdConnectEvents.cs
index b7c90b0026..59401945b8 100644
--- a/shared/Mocks/OpenIdConnect/TestOpenIdConnectEvents.cs
+++ b/shared/Mocks/OpenIdConnect/TestOpenIdConnectEvents.cs
@@ -1,9 +1,9 @@
-#if TESTING
+#if TESTING
using System.Collections.Generic;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authentication.OpenIdConnect;
-using Microsoft.AspNet.Http;
+using Microsoft.AspNetCore.Authentication.OpenIdConnect;
+using Microsoft.AspNetCore.Http;
using Microsoft.IdentityModel.Protocols.OpenIdConnect;
using MusicStore.Mocks.Common;
diff --git a/shared/Mocks/StartupOpenIdConnectTesting.cs b/shared/Mocks/StartupOpenIdConnectTesting.cs
index 4dca087fd9..7b4fac8dbe 100644
--- a/shared/Mocks/StartupOpenIdConnectTesting.cs
+++ b/shared/Mocks/StartupOpenIdConnectTesting.cs
@@ -1,11 +1,11 @@
#if TESTING
using System;
-using Microsoft.AspNet.Authentication.OpenIdConnect;
-using Microsoft.AspNet.Authorization;
-using Microsoft.AspNet.Builder;
-using Microsoft.AspNet.Diagnostics.Entity;
-using Microsoft.AspNet.Identity.EntityFramework;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Authentication.OpenIdConnect;
+using Microsoft.AspNetCore.Authorization;
+using Microsoft.AspNetCore.Builder;
+using Microsoft.AspNetCore.Diagnostics.EntityFrameworkCore;
+using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.PlatformAbstractions;
using Microsoft.Extensions.Caching.Memory;
using Microsoft.Extensions.Configuration;
diff --git a/shared/Mocks/StartupSocialTesting.cs b/shared/Mocks/StartupSocialTesting.cs
index 3ff7f6c423..369bd89ed3 100644
--- a/shared/Mocks/StartupSocialTesting.cs
+++ b/shared/Mocks/StartupSocialTesting.cs
@@ -1,13 +1,13 @@
#if TESTING
using System;
-using Microsoft.AspNet.Authentication.OAuth;
-using Microsoft.AspNet.Authentication.Twitter;
-using Microsoft.AspNet.Authorization;
-using Microsoft.AspNet.Builder;
-using Microsoft.AspNet.Diagnostics.Entity;
-using Microsoft.AspNet.Http;
-using Microsoft.AspNet.Identity.EntityFramework;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Authentication.OAuth;
+using Microsoft.AspNetCore.Authentication.Twitter;
+using Microsoft.AspNetCore.Authorization;
+using Microsoft.AspNetCore.Builder;
+using Microsoft.AspNetCore.Diagnostics.EntityFrameworkCore;
+using Microsoft.AspNetCore.Http;
+using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.PlatformAbstractions;
using Microsoft.Extensions.Caching.Memory;
using Microsoft.Extensions.Configuration;
diff --git a/shared/Mocks/Twitter/CustomTwitterStateDataFormat.cs b/shared/Mocks/Twitter/CustomTwitterStateDataFormat.cs
index 6b6a1e33a9..0c39e3c0d4 100644
--- a/shared/Mocks/Twitter/CustomTwitterStateDataFormat.cs
+++ b/shared/Mocks/Twitter/CustomTwitterStateDataFormat.cs
@@ -1,6 +1,6 @@
-#if TESTING
-using Microsoft.AspNet.Authentication;
-using Microsoft.AspNet.Authentication.Twitter;
+#if TESTING
+using Microsoft.AspNetCore.Authentication;
+using Microsoft.AspNetCore.Authentication.Twitter;
using Newtonsoft.Json;
namespace MusicStore.Mocks.Twitter
diff --git a/shared/Mocks/Twitter/TestTwitterEvents.cs b/shared/Mocks/Twitter/TestTwitterEvents.cs
index f10d4de0b9..414a7a8ebd 100644
--- a/shared/Mocks/Twitter/TestTwitterEvents.cs
+++ b/shared/Mocks/Twitter/TestTwitterEvents.cs
@@ -1,10 +1,10 @@
-#if TESTING
+#if TESTING
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authentication;
-using Microsoft.AspNet.Authentication.Twitter;
-using Microsoft.AspNet.Identity;
+using Microsoft.AspNetCore.Authentication;
+using Microsoft.AspNetCore.Authentication.Twitter;
+using Microsoft.AspNetCore.Identity;
using MusicStore.Mocks.Common;
namespace MusicStore.Mocks.Twitter
diff --git a/shared/Mocks/Twitter/TwitterMockBackChannelHttpHandler.cs b/shared/Mocks/Twitter/TwitterMockBackChannelHttpHandler.cs
index c689840c42..df750a5c55 100644
--- a/shared/Mocks/Twitter/TwitterMockBackChannelHttpHandler.cs
+++ b/shared/Mocks/Twitter/TwitterMockBackChannelHttpHandler.cs
@@ -1,12 +1,12 @@
-#if TESTING
+#if TESTING
using System;
using System.Collections.Generic;
using System.Net;
using System.Net.Http;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
namespace MusicStore.Mocks.Twitter
{
diff --git a/src/MusicStore/Areas/Admin/Controllers/StoreManagerController.cs b/src/MusicStore/Areas/Admin/Controllers/StoreManagerController.cs
index 121282fbef..917038a426 100644
--- a/src/MusicStore/Areas/Admin/Controllers/StoreManagerController.cs
+++ b/src/MusicStore/Areas/Admin/Controllers/StoreManagerController.cs
@@ -2,11 +2,11 @@ using System;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authorization;
-using Microsoft.AspNet.Cors;
-using Microsoft.AspNet.Mvc;
-using Microsoft.AspNet.Mvc.Rendering;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Authorization;
+using Microsoft.AspNetCore.Cors;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.AspNetCore.Mvc.Rendering;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Caching.Memory;
using MusicStore.Models;
using MusicStore.ViewModels;
diff --git a/src/MusicStore/Components/CartSummaryComponent.cs b/src/MusicStore/Components/CartSummaryComponent.cs
index ca93288150..61e5306adb 100644
--- a/src/MusicStore/Components/CartSummaryComponent.cs
+++ b/src/MusicStore/Components/CartSummaryComponent.cs
@@ -1,6 +1,6 @@
-using System.Linq;
+using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Mvc;
+using Microsoft.AspNetCore.Mvc;
using MusicStore.Models;
namespace MusicStore.Components
diff --git a/src/MusicStore/Components/GenreMenuComponent.cs b/src/MusicStore/Components/GenreMenuComponent.cs
index 7f48ecd1ec..20f73528e2 100644
--- a/src/MusicStore/Components/GenreMenuComponent.cs
+++ b/src/MusicStore/Components/GenreMenuComponent.cs
@@ -1,8 +1,8 @@
-using System.Collections.Generic;
+using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using MusicStore.Models;
namespace MusicStore.Components
diff --git a/src/MusicStore/Controllers/AccountController.cs b/src/MusicStore/Controllers/AccountController.cs
index 8fc94f9f5a..a59e76663a 100644
--- a/src/MusicStore/Controllers/AccountController.cs
+++ b/src/MusicStore/Controllers/AccountController.cs
@@ -1,11 +1,11 @@
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authorization;
-using Microsoft.AspNet.Hosting;
-using Microsoft.AspNet.Identity;
-using Microsoft.AspNet.Mvc;
-using Microsoft.AspNet.Mvc.Rendering;
+using Microsoft.AspNetCore.Authorization;
+using Microsoft.AspNetCore.Hosting;
+using Microsoft.AspNetCore.Identity;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.AspNetCore.Mvc.Rendering;
using Microsoft.Extensions.DependencyInjection;
using MusicStore.Models;
diff --git a/src/MusicStore/Controllers/CheckoutController.cs b/src/MusicStore/Controllers/CheckoutController.cs
index 8fec6f1720..56ed9116ea 100644
--- a/src/MusicStore/Controllers/CheckoutController.cs
+++ b/src/MusicStore/Controllers/CheckoutController.cs
@@ -1,11 +1,11 @@
-using System;
+using System;
using System.Linq;
using System.Security.Claims;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authorization;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Authorization;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using MusicStore.Models;
namespace MusicStore.Controllers
diff --git a/src/MusicStore/Controllers/HomeController.cs b/src/MusicStore/Controllers/HomeController.cs
index 50c0bbb1e3..df110fac42 100644
--- a/src/MusicStore/Controllers/HomeController.cs
+++ b/src/MusicStore/Controllers/HomeController.cs
@@ -2,8 +2,8 @@ using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Caching.Memory;
using MusicStore.Models;
diff --git a/src/MusicStore/Controllers/ManageController.cs b/src/MusicStore/Controllers/ManageController.cs
index 64a0845b2f..b6f21021db 100644
--- a/src/MusicStore/Controllers/ManageController.cs
+++ b/src/MusicStore/Controllers/ManageController.cs
@@ -1,9 +1,9 @@
-using System.Linq;
+using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Authorization;
-using Microsoft.AspNet.Identity;
-using Microsoft.AspNet.Mvc;
+using Microsoft.AspNetCore.Authorization;
+using Microsoft.AspNetCore.Identity;
+using Microsoft.AspNetCore.Mvc;
using MusicStore.Models;
namespace MusicStore.Controllers
diff --git a/src/MusicStore/Controllers/ShoppingCartController.cs b/src/MusicStore/Controllers/ShoppingCartController.cs
index 71bf0a6ba2..d2bfb401fb 100644
--- a/src/MusicStore/Controllers/ShoppingCartController.cs
+++ b/src/MusicStore/Controllers/ShoppingCartController.cs
@@ -1,8 +1,8 @@
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using MusicStore.Models;
using MusicStore.ViewModels;
diff --git a/src/MusicStore/Controllers/StoreController.cs b/src/MusicStore/Controllers/StoreController.cs
index 250b31c3e6..e3c21e345a 100644
--- a/src/MusicStore/Controllers/StoreController.cs
+++ b/src/MusicStore/Controllers/StoreController.cs
@@ -1,8 +1,8 @@
using System;
using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Caching.Memory;
using MusicStore.Models;
diff --git a/src/MusicStore/Models/AccountViewModels.cs b/src/MusicStore/Models/AccountViewModels.cs
index 38a9735292..8b566d2dbd 100644
--- a/src/MusicStore/Models/AccountViewModels.cs
+++ b/src/MusicStore/Models/AccountViewModels.cs
@@ -1,6 +1,6 @@
-using System.Collections.Generic;
+using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
-using Microsoft.AspNet.Mvc.Rendering;
+using Microsoft.AspNetCore.Mvc.Rendering;
namespace MusicStore.Models
{
diff --git a/src/MusicStore/Models/Album.cs b/src/MusicStore/Models/Album.cs
index bd0aafd6d3..9f333006ec 100644
--- a/src/MusicStore/Models/Album.cs
+++ b/src/MusicStore/Models/Album.cs
@@ -1,7 +1,7 @@
-using System;
+using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
-using Microsoft.AspNet.Mvc.ModelBinding;
+using Microsoft.AspNetCore.Mvc.ModelBinding;
namespace MusicStore.Models
{
diff --git a/src/MusicStore/Models/ManageViewModels.cs b/src/MusicStore/Models/ManageViewModels.cs
index f7252f21d1..e91224cce5 100644
--- a/src/MusicStore/Models/ManageViewModels.cs
+++ b/src/MusicStore/Models/ManageViewModels.cs
@@ -1,8 +1,8 @@
-using System.Collections.Generic;
+using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
-using Microsoft.AspNet.Http.Authentication;
-using Microsoft.AspNet.Identity;
-using Microsoft.AspNet.Mvc.Rendering;
+using Microsoft.AspNetCore.Http.Authentication;
+using Microsoft.AspNetCore.Identity;
+using Microsoft.AspNetCore.Mvc.Rendering;
namespace MusicStore.Models
{
diff --git a/src/MusicStore/Models/MusicStoreContext.cs b/src/MusicStore/Models/MusicStoreContext.cs
index 7fc9f17569..89a7f14922 100644
--- a/src/MusicStore/Models/MusicStoreContext.cs
+++ b/src/MusicStore/Models/MusicStoreContext.cs
@@ -1,5 +1,5 @@
-using Microsoft.AspNet.Identity.EntityFramework;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
+using Microsoft.EntityFrameworkCore;
namespace MusicStore.Models
{
diff --git a/src/MusicStore/Models/Order.cs b/src/MusicStore/Models/Order.cs
index 1d9b12dd3e..2b0bcfd145 100644
--- a/src/MusicStore/Models/Order.cs
+++ b/src/MusicStore/Models/Order.cs
@@ -1,6 +1,6 @@
-using System.Collections.Generic;
+using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
-using Microsoft.AspNet.Mvc.ModelBinding;
+using Microsoft.AspNetCore.Mvc.ModelBinding;
namespace MusicStore.Models
{
diff --git a/src/MusicStore/Models/SampleData.cs b/src/MusicStore/Models/SampleData.cs
index b87e28eb85..835bdd1f96 100644
--- a/src/MusicStore/Models/SampleData.cs
+++ b/src/MusicStore/Models/SampleData.cs
@@ -3,8 +3,8 @@ using System.Collections.Generic;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Identity;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Identity;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.PlatformAbstractions;
diff --git a/src/MusicStore/Models/ShoppingCart.cs b/src/MusicStore/Models/ShoppingCart.cs
index abcec5b572..c963609107 100644
--- a/src/MusicStore/Models/ShoppingCart.cs
+++ b/src/MusicStore/Models/ShoppingCart.cs
@@ -1,9 +1,9 @@
-using System;
+using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Http;
+using Microsoft.EntityFrameworkCore;
namespace MusicStore.Models
{
diff --git a/src/MusicStore/Program.cs b/src/MusicStore/Program.cs
index aa772a8e14..a1b20f160a 100644
--- a/src/MusicStore/Program.cs
+++ b/src/MusicStore/Program.cs
@@ -1,4 +1,4 @@
-using Microsoft.AspNet.Hosting;
+using Microsoft.AspNetCore.Hosting;
namespace MusicStore
{
diff --git a/src/MusicStore/Startup.cs b/src/MusicStore/Startup.cs
index 4ae206f7d9..2972fdbf2c 100644
--- a/src/MusicStore/Startup.cs
+++ b/src/MusicStore/Startup.cs
@@ -1,6 +1,6 @@
-using Microsoft.AspNet.Builder;
-using Microsoft.AspNet.Identity.EntityFramework;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Builder;
+using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
diff --git a/src/MusicStore/TestMIddleware.cs b/src/MusicStore/TestMIddleware.cs
index e35089a65f..f13f129909 100644
--- a/src/MusicStore/TestMIddleware.cs
+++ b/src/MusicStore/TestMIddleware.cs
@@ -1,9 +1,9 @@
-using System;
+using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http;
+using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;
namespace MusicStore
diff --git a/src/MusicStore/Views/Shared/_LoginPartial.cshtml b/src/MusicStore/Views/Shared/_LoginPartial.cshtml
index 30eef95392..64e7b91ed8 100644
--- a/src/MusicStore/Views/Shared/_LoginPartial.cshtml
+++ b/src/MusicStore/Views/Shared/_LoginPartial.cshtml
@@ -1,4 +1,4 @@
-@using Microsoft.AspNet.Identity
+@using Microsoft.AspNetCore.Identity
@using MusicStore.Models
@inject SignInManager SignInManager
diff --git a/src/MusicStore/Views/ShoppingCart/Index.cshtml b/src/MusicStore/Views/ShoppingCart/Index.cshtml
index 421141865f..752a30de04 100644
--- a/src/MusicStore/Views/ShoppingCart/Index.cshtml
+++ b/src/MusicStore/Views/ShoppingCart/Index.cshtml
@@ -1,5 +1,5 @@
-@model MusicStore.ViewModels.ShoppingCartViewModel
-@inject Microsoft.AspNet.Antiforgery.IAntiforgery Xsrf
+@model MusicStore.ViewModels.ShoppingCartViewModel
+@inject Microsoft.AspNetCore.Antiforgery.IAntiforgery Xsrf
@{
ViewBag.Title = "Shopping Cart";
}
diff --git a/src/MusicStore/Views/_ViewImports.cshtml b/src/MusicStore/Views/_ViewImports.cshtml
index 613ced28d4..fa2866b715 100644
--- a/src/MusicStore/Views/_ViewImports.cshtml
+++ b/src/MusicStore/Views/_ViewImports.cshtml
@@ -1,5 +1,5 @@
@using MusicStore
@using MusicStore.Models
@using Microsoft.Extensions.Options
-@using Microsoft.AspNet.Identity
-@addTagHelper *, Microsoft.AspNet.Mvc.TagHelpers
+@using Microsoft.AspNetCore.Identity
+@addTagHelper *, Microsoft.AspNetCore.Mvc.TagHelpers
diff --git a/src/MusicStore/hosting.json b/src/MusicStore/hosting.json
index f8ef14574d..6a93dbafa8 100644
--- a/src/MusicStore/hosting.json
+++ b/src/MusicStore/hosting.json
@@ -1,3 +1,3 @@
-{
- "server": "Microsoft.AspNet.Server.Kestrel"
+{
+ "server": "Microsoft.AspNetCore.Server.Kestrel"
}
diff --git a/src/MusicStore/project.json b/src/MusicStore/project.json
index 31b29f0542..37e1a5ffe3 100644
--- a/src/MusicStore/project.json
+++ b/src/MusicStore/project.json
@@ -14,24 +14,24 @@
],
"publishExclude": "*.cmd",
"dependencies": {
- "EntityFramework.InMemory": "7.0.0-*",
- "EntityFramework.MicrosoftSqlServer": "7.0.0-*",
- "Microsoft.AspNet.Authentication.Cookies": "1.0.0-*",
- "Microsoft.AspNet.Authentication.Facebook": "1.0.0-*",
- "Microsoft.AspNet.Authentication.Google": "1.0.0-*",
- "Microsoft.AspNet.Authentication.MicrosoftAccount": "1.0.0-*",
- "Microsoft.AspNet.Authentication.OpenIdConnect": "1.0.0-*",
- "Microsoft.AspNet.Authentication.Twitter": "1.0.0-*",
- "Microsoft.AspNet.Diagnostics.Entity": "7.0.0-*",
- "Microsoft.AspNet.Identity.EntityFramework": "3.0.0-*",
- "Microsoft.AspNet.IISPlatformHandler": "1.0.0-*",
- "Microsoft.AspNet.Mvc": "6.0.0-*",
- "Microsoft.AspNet.Mvc.TagHelpers": "6.0.0-*",
- "Microsoft.AspNet.Server.Kestrel": "1.0.0-*",
- "Microsoft.AspNet.Server.WebListener": "1.0.0-*",
- "Microsoft.AspNet.Session": "1.0.0-*",
- "Microsoft.AspNet.StaticFiles": "1.0.0-*",
- "Microsoft.AspNet.Tooling.Razor": "1.0.0-*",
+ "Microsoft.EntityFrameworkCore.InMemory": "7.0.0-*",
+ "Microsoft.EntityFrameworkCore.SqlServer": "7.0.0-*",
+ "Microsoft.AspNetCore.Authentication.Cookies": "1.0.0-*",
+ "Microsoft.AspNetCore.Authentication.Facebook": "1.0.0-*",
+ "Microsoft.AspNetCore.Authentication.Google": "1.0.0-*",
+ "Microsoft.AspNetCore.Authentication.MicrosoftAccount": "1.0.0-*",
+ "Microsoft.AspNetCore.Authentication.OpenIdConnect": "1.0.0-*",
+ "Microsoft.AspNetCore.Authentication.Twitter": "1.0.0-*",
+ "Microsoft.AspNetCore.Diagnostics.EntityFrameworkCore": "7.0.0-*",
+ "Microsoft.AspNetCore.Identity.EntityFrameworkCore": "3.0.0-*",
+ "Microsoft.AspNetCore.IISPlatformHandler": "1.0.0-*",
+ "Microsoft.AspNetCore.Mvc": "6.0.0-*",
+ "Microsoft.AspNetCore.Mvc.TagHelpers": "6.0.0-*",
+ "Microsoft.AspNetCore.Server.Kestrel": "1.0.0-*",
+ "Microsoft.AspNetCore.Server.WebListener": "1.0.0-*",
+ "Microsoft.AspNetCore.Session": "1.0.0-*",
+ "Microsoft.AspNetCore.StaticFiles": "1.0.0-*",
+ "Microsoft.AspNetCore.Tooling.Razor": "1.0.0-*",
"Microsoft.Extensions.CodeGenerators.Mvc": "1.0.0-*",
"Microsoft.Extensions.Configuration.CommandLine": "1.0.0-*",
"Microsoft.Extensions.Configuration.EnvironmentVariables": "1.0.0-*",
diff --git a/test/E2ETests/Common/Helpers.cs b/test/E2ETests/Common/Helpers.cs
index d9051a8102..5d76b4aef3 100644
--- a/test/E2ETests/Common/Helpers.cs
+++ b/test/E2ETests/Common/Helpers.cs
@@ -1,7 +1,7 @@
using System;
using System.IO;
using System.Linq;
-using Microsoft.AspNet.Server.Testing;
+using Microsoft.AspNetCore.Server.Testing;
using Microsoft.Extensions.Logging;
namespace E2ETests
diff --git a/test/E2ETests/Implementation/FacebookLoginScenarios.cs b/test/E2ETests/Implementation/FacebookLoginScenarios.cs
index 0f98e0c34f..6f58a80015 100644
--- a/test/E2ETests/Implementation/FacebookLoginScenarios.cs
+++ b/test/E2ETests/Implementation/FacebookLoginScenarios.cs
@@ -3,8 +3,8 @@ using System.Collections.Generic;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
using Microsoft.Extensions.Logging;
using Xunit;
@@ -86,8 +86,8 @@ namespace E2ETests
Assert.Contains(string.Format("Hello {0}!", "AspnetvnextTest@test.com"), responseContent, StringComparison.OrdinalIgnoreCase);
Assert.Contains("Log off", responseContent, StringComparison.OrdinalIgnoreCase);
//Verify cookie sent
- Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
- Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.ExternalLogin"));
+ Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
+ Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.ExternalLogin"));
_logger.LogInformation("Successfully signed in with user '{email}'", "AspnetvnextTest@test.com");
_logger.LogInformation("Verifying if the middleware events were fired");
diff --git a/test/E2ETests/Implementation/GoogleLoginScenarios.cs b/test/E2ETests/Implementation/GoogleLoginScenarios.cs
index a75c1a0a1e..66e40c921e 100644
--- a/test/E2ETests/Implementation/GoogleLoginScenarios.cs
+++ b/test/E2ETests/Implementation/GoogleLoginScenarios.cs
@@ -3,8 +3,8 @@ using System.Collections.Generic;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
using Microsoft.Extensions.Logging;
using Xunit;
@@ -87,8 +87,8 @@ namespace E2ETests
Assert.Contains(string.Format("Hello {0}!", "AspnetvnextTest@gmail.com"), responseContent, StringComparison.OrdinalIgnoreCase);
Assert.Contains("Log off", responseContent, StringComparison.OrdinalIgnoreCase);
//Verify cookie sent
- Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
- Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.ExternalLogin"));
+ Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
+ Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.ExternalLogin"));
_logger.LogInformation("Successfully signed in with user '{email}'", "AspnetvnextTest@gmail.com");
_logger.LogInformation("Verifying if the middleware events were fired");
diff --git a/test/E2ETests/Implementation/MicrosoftAccountAuthenticationScenarios.cs b/test/E2ETests/Implementation/MicrosoftAccountAuthenticationScenarios.cs
index eba31511e4..697e1f1f26 100644
--- a/test/E2ETests/Implementation/MicrosoftAccountAuthenticationScenarios.cs
+++ b/test/E2ETests/Implementation/MicrosoftAccountAuthenticationScenarios.cs
@@ -3,8 +3,8 @@ using System.Collections.Generic;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
using Microsoft.Extensions.Logging;
using Xunit;
@@ -86,8 +86,8 @@ namespace E2ETests
Assert.Contains(string.Format("Hello {0}!", "microsoft@test.com"), responseContent, StringComparison.OrdinalIgnoreCase);
Assert.Contains("Log off", responseContent, StringComparison.OrdinalIgnoreCase);
//Verify cookie sent
- Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
- Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.ExternalLogin"));
+ Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
+ Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.ExternalLogin"));
_logger.LogInformation("Successfully signed in with user '{email}'", "microsoft@test.com");
_logger.LogInformation("Verifying if the middleware events were fired");
diff --git a/test/E2ETests/Implementation/OpenIdConnectLoginScenarios.cs b/test/E2ETests/Implementation/OpenIdConnectLoginScenarios.cs
index 6f22003973..d7e865fa8d 100644
--- a/test/E2ETests/Implementation/OpenIdConnectLoginScenarios.cs
+++ b/test/E2ETests/Implementation/OpenIdConnectLoginScenarios.cs
@@ -3,8 +3,8 @@ using System.Collections.Generic;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
using Microsoft.Extensions.Logging;
using Xunit;
@@ -73,8 +73,8 @@ namespace E2ETests
Assert.Contains(string.Format("Hello {0}!", "User3@aspnettest.onmicrosoft.com"), responseContent, StringComparison.OrdinalIgnoreCase);
Assert.Contains("Log off", responseContent, StringComparison.OrdinalIgnoreCase);
//Verify cookie sent
- Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
- Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.ExternalLogin"));
+ Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
+ Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.ExternalLogin"));
_logger.LogInformation("Successfully signed in with user '{email}'", "User3@aspnettest.onmicrosoft.com");
_logger.LogInformation("Verifying if the middleware events were fired");
@@ -101,7 +101,7 @@ namespace E2ETests
_httpClient = new HttpClient(handler) { BaseAddress = new Uri(_deploymentResult.ApplicationBaseUri) };
response = await _httpClient.PostAsync("Account/LogOff", content);
- Assert.Null(handler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
+ Assert.Null(handler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
Assert.Equal(
"https://login.windows.net/4afbc689-805b-48cf-a24c-d4aa3248a248/oauth2/logout",
response.Headers.Location.AbsoluteUri.Replace(response.Headers.Location.Query, string.Empty));
diff --git a/test/E2ETests/Implementation/TwitterLoginScenarios.cs b/test/E2ETests/Implementation/TwitterLoginScenarios.cs
index 00d969098b..b174d7d753 100644
--- a/test/E2ETests/Implementation/TwitterLoginScenarios.cs
+++ b/test/E2ETests/Implementation/TwitterLoginScenarios.cs
@@ -3,8 +3,8 @@ using System.Collections.Generic;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.WebUtilities;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.WebUtilities;
using Microsoft.Extensions.Logging;
using Xunit;
@@ -86,8 +86,8 @@ namespace E2ETests
Assert.Contains(string.Format("Hello {0}!", "twitter@test.com"), responseContent, StringComparison.OrdinalIgnoreCase);
Assert.Contains("Log off", responseContent, StringComparison.OrdinalIgnoreCase);
//Verify cookie sent
- Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
- Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.ExternalLogin"));
+ Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
+ Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.ExternalLogin"));
_logger.LogInformation("Successfully signed in with user '{email}'", "twitter@test.com");
_logger.LogInformation("Verifying if the middleware events were fired");
diff --git a/test/E2ETests/Implementation/Validator.cs b/test/E2ETests/Implementation/Validator.cs
index b5e9592924..0097c06dc6 100644
--- a/test/E2ETests/Implementation/Validator.cs
+++ b/test/E2ETests/Implementation/Validator.cs
@@ -4,7 +4,7 @@ using System.Linq;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Server.Testing;
+using Microsoft.AspNetCore.Server.Testing;
using Microsoft.Extensions.Logging;
using Xunit;
@@ -178,7 +178,7 @@ namespace E2ETests
var content = new FormUrlEncodedContent(formParameters.ToArray());
response = await _httpClient.PostAsync("Account/Register", content);
responseContent = await response.Content.ReadAsStringAsync();
- Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
+ Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
Assert.Contains("- The password and confirmation password do not match.
", responseContent, StringComparison.OrdinalIgnoreCase);
_logger.LogInformation("Server side model validator rejected the user '{email}''s registration as passwords do not match.", generatedEmail);
}
@@ -265,7 +265,7 @@ namespace E2ETests
Assert.Contains("www.github.com/aspnet/MusicStore", responseContent, StringComparison.OrdinalIgnoreCase);
Assert.Contains("/Images/home-showcase.png", responseContent, StringComparison.OrdinalIgnoreCase);
//Verify cookie cleared on logout
- Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
+ Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
_logger.LogInformation("Successfully signed out of '{email}''s session", email);
}
else
@@ -294,7 +294,7 @@ namespace E2ETests
responseContent = await response.Content.ReadAsStringAsync();
Assert.Contains("- Invalid login attempt.
", responseContent, StringComparison.OrdinalIgnoreCase);
//Verify cookie not sent
- Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
+ Assert.Null(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
_logger.LogInformation("Identity successfully prevented an invalid user login.");
}
@@ -318,7 +318,7 @@ namespace E2ETests
Assert.Contains(string.Format("Hello {0}!", email), responseContent, StringComparison.OrdinalIgnoreCase);
Assert.Contains("Log off", responseContent, StringComparison.OrdinalIgnoreCase);
//Verify cookie sent
- Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
+ Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
_logger.LogInformation("Successfully signed in with user '{email}'", email);
}
@@ -340,7 +340,7 @@ namespace E2ETests
response = await _httpClient.GetAsync(response.Headers.Location);
responseContent = await response.Content.ReadAsStringAsync();
Assert.Contains("Your password has been changed.", responseContent, StringComparison.OrdinalIgnoreCase);
- Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNet.Identity.Application"));
+ Assert.NotNull(_httpClientHandler.CookieContainer.GetCookies(new Uri(_deploymentResult.ApplicationBaseUri)).GetCookieWithName(".AspNet.Microsoft.AspNetCore.Identity.Application"));
_logger.LogInformation("Successfully changed the password for user '{email}'", email);
}
diff --git a/test/E2ETests/NtlmAuthentationTest.cs b/test/E2ETests/NtlmAuthentationTest.cs
index 71f2c61736..9f16cd4e1f 100644
--- a/test/E2ETests/NtlmAuthentationTest.cs
+++ b/test/E2ETests/NtlmAuthentationTest.cs
@@ -3,8 +3,8 @@ using System.Collections.Generic;
using System.IO;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Server.Testing;
-using Microsoft.AspNet.Testing.xunit;
+using Microsoft.AspNetCore.Server.Testing;
+using Microsoft.AspNetCore.Testing.xunit;
using Microsoft.Extensions.Logging;
using Xunit;
diff --git a/test/E2ETests/OpenIdConnectTests.cs b/test/E2ETests/OpenIdConnectTests.cs
index d528aed34f..36fe35783e 100644
--- a/test/E2ETests/OpenIdConnectTests.cs
+++ b/test/E2ETests/OpenIdConnectTests.cs
@@ -2,9 +2,9 @@ using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Server.Testing;
-using Microsoft.AspNet.Testing;
-using Microsoft.AspNet.Testing.xunit;
+using Microsoft.AspNetCore.Server.Testing;
+using Microsoft.AspNetCore.Testing;
+using Microsoft.AspNetCore.Testing.xunit;
using Microsoft.Extensions.Logging;
using Xunit;
diff --git a/test/E2ETests/PublishAndRunTests.cs b/test/E2ETests/PublishAndRunTests.cs
index 67ee12b6fe..f2501b209b 100644
--- a/test/E2ETests/PublishAndRunTests.cs
+++ b/test/E2ETests/PublishAndRunTests.cs
@@ -3,9 +3,9 @@ using System.Collections.Generic;
using System.IO;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Server.Testing;
-using Microsoft.AspNet.Testing;
-using Microsoft.AspNet.Testing.xunit;
+using Microsoft.AspNetCore.Server.Testing;
+using Microsoft.AspNetCore.Testing;
+using Microsoft.AspNetCore.Testing.xunit;
using Microsoft.Extensions.Logging;
using Xunit;
diff --git a/test/E2ETests/SmokeTests.cs b/test/E2ETests/SmokeTests.cs
index f0bfa53dd7..b5740e0a16 100644
--- a/test/E2ETests/SmokeTests.cs
+++ b/test/E2ETests/SmokeTests.cs
@@ -2,9 +2,9 @@ using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Server.Testing;
-using Microsoft.AspNet.Testing;
-using Microsoft.AspNet.Testing.xunit;
+using Microsoft.AspNetCore.Server.Testing;
+using Microsoft.AspNetCore.Testing;
+using Microsoft.AspNetCore.Testing.xunit;
using Microsoft.Extensions.Logging;
using Xunit;
diff --git a/test/E2ETests/project.json b/test/E2ETests/project.json
index d3a69c0574..e4d0c397f1 100644
--- a/test/E2ETests/project.json
+++ b/test/E2ETests/project.json
@@ -9,9 +9,9 @@
"test": "xunit.runner.aspnet"
},
"dependencies": {
- "Microsoft.AspNet.Authentication.OpenIdConnect": "1.0.0-*",
- "Microsoft.AspNet.Server.Testing": "1.0.0-*",
- "Microsoft.AspNet.WebUtilities": "1.0.0-*",
+ "Microsoft.AspNetCore.Authentication.OpenIdConnect": "1.0.0-*",
+ "Microsoft.AspNetCore.Server.Testing": "1.0.0-*",
+ "Microsoft.AspNetCore.WebUtilities": "1.0.0-*",
"Microsoft.Extensions.Configuration.EnvironmentVariables": "1.0.0-*",
"Microsoft.Extensions.Logging.Console": "1.0.0-*",
"xunit.runner.aspnet": "2.0.0-aspnet-*"
diff --git a/test/MusicStore.Test/CartSummaryComponentTest.cs b/test/MusicStore.Test/CartSummaryComponentTest.cs
index 60e5989bfe..9233fac327 100644
--- a/test/MusicStore.Test/CartSummaryComponentTest.cs
+++ b/test/MusicStore.Test/CartSummaryComponentTest.cs
@@ -1,11 +1,11 @@
using System;
using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.Mvc.Rendering;
-using Microsoft.AspNet.Mvc.ViewComponents;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Http;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.Mvc.Rendering;
+using Microsoft.AspNetCore.Mvc.ViewComponents;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.DependencyInjection;
using MusicStore.Controllers;
using MusicStore.Models;
diff --git a/test/MusicStore.Test/CheckoutControllerTest.cs b/test/MusicStore.Test/CheckoutControllerTest.cs
index 267527fcae..8365ba7fe3 100644
--- a/test/MusicStore.Test/CheckoutControllerTest.cs
+++ b/test/MusicStore.Test/CheckoutControllerTest.cs
@@ -4,10 +4,10 @@ using System.Linq;
using System.Security.Claims;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Http;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Primitives;
using MusicStore.Models;
diff --git a/test/MusicStore.Test/GenreMenuComponentTest.cs b/test/MusicStore.Test/GenreMenuComponentTest.cs
index 7056acdc3c..f0c9b02d3c 100644
--- a/test/MusicStore.Test/GenreMenuComponentTest.cs
+++ b/test/MusicStore.Test/GenreMenuComponentTest.cs
@@ -2,8 +2,8 @@ using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Mvc.ViewComponents;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Mvc.ViewComponents;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.DependencyInjection;
using MusicStore.Models;
using Xunit;
diff --git a/test/MusicStore.Test/HomeControllerTest.cs b/test/MusicStore.Test/HomeControllerTest.cs
index dd2b92cab7..cb2fbe3d4b 100644
--- a/test/MusicStore.Test/HomeControllerTest.cs
+++ b/test/MusicStore.Test/HomeControllerTest.cs
@@ -2,8 +2,8 @@ using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Caching.Memory;
using Microsoft.Extensions.DependencyInjection;
using MusicStore.Models;
diff --git a/test/MusicStore.Test/ManageControllerTest.cs b/test/MusicStore.Test/ManageControllerTest.cs
index 942c72439a..4c7b63618d 100644
--- a/test/MusicStore.Test/ManageControllerTest.cs
+++ b/test/MusicStore.Test/ManageControllerTest.cs
@@ -2,15 +2,15 @@ using System;
using System.Collections.Generic;
using System.Security.Claims;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http;
-using Microsoft.AspNet.Http.Features;
-using Microsoft.AspNet.Http.Features.Authentication;
-using Microsoft.AspNet.Http.Features.Authentication.Internal;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.Identity;
-using Microsoft.AspNet.Identity.EntityFramework;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Http;
+using Microsoft.AspNetCore.Http.Features;
+using Microsoft.AspNetCore.Http.Features.Authentication;
+using Microsoft.AspNetCore.Http.Features.Authentication.Internal;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.Identity;
+using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.DependencyInjection;
using MusicStore.Models;
using Xunit;
diff --git a/test/MusicStore.Test/ShoppingCartControllerTest.cs b/test/MusicStore.Test/ShoppingCartControllerTest.cs
index 38a0d4f54a..437d2bba72 100644
--- a/test/MusicStore.Test/ShoppingCartControllerTest.cs
+++ b/test/MusicStore.Test/ShoppingCartControllerTest.cs
@@ -3,13 +3,13 @@ using System.Collections.Generic;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
-using Microsoft.AspNet.Antiforgery;
-using Microsoft.AspNet.Http;
-using Microsoft.AspNet.Http.Features;
-using Microsoft.AspNet.Http.Features.Internal;
-using Microsoft.AspNet.Http.Internal;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Antiforgery;
+using Microsoft.AspNetCore.Http;
+using Microsoft.AspNetCore.Http.Features;
+using Microsoft.AspNetCore.Http.Features.Internal;
+using Microsoft.AspNetCore.Http.Internal;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Primitives;
using MusicStore.Models;
diff --git a/test/MusicStore.Test/StoreControllerTest.cs b/test/MusicStore.Test/StoreControllerTest.cs
index 4d16070fe2..001933e8e9 100644
--- a/test/MusicStore.Test/StoreControllerTest.cs
+++ b/test/MusicStore.Test/StoreControllerTest.cs
@@ -2,8 +2,8 @@ using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
-using Microsoft.AspNet.Mvc;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Mvc;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Caching.Memory;
using Microsoft.Extensions.DependencyInjection;
using MusicStore.Models;
diff --git a/test/MusicStore.Test/TestSession.cs b/test/MusicStore.Test/TestSession.cs
index 8a69105651..84b4b12c3e 100644
--- a/test/MusicStore.Test/TestSession.cs
+++ b/test/MusicStore.Test/TestSession.cs
@@ -1,7 +1,7 @@
-using System;
+using System;
using System.Collections.Generic;
using System.Threading.Tasks;
-using Microsoft.AspNet.Http.Features;
+using Microsoft.AspNetCore.Http.Features;
namespace MusicStore.Controllers
{
diff --git a/src/MusicStore/StartupNtlmAuthentication.cs b/src/MusicStore/StartupNtlmAuthentication.cs
index 5630148010..d8b8c0f36b 100644
--- a/src/MusicStore/StartupNtlmAuthentication.cs
+++ b/src/MusicStore/StartupNtlmAuthentication.cs
@@ -1,8 +1,8 @@
using System;
using System.Security.Claims;
-using Microsoft.AspNet.Builder;
-using Microsoft.AspNet.Http.Features;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Builder;
+using Microsoft.AspNetCore.Http.Features;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
@@ -15,7 +15,7 @@ namespace MusicStore
{
///
/// To make runtime to load an environment based startup class, specify the environment by the following ways:
/// 1. Drop a Microsoft.AspNet.Hosting.ini file in the wwwroot folder
/// 2. Add a setting in the ini file named 'ASPNET_ENV' with value of the format 'Startup[EnvironmentName]'.
/// For example: To load a Startup class named 'StartupNtlmAuthentication' the value of the env should be
/// 'NtlmAuthentication' (eg. ASPNET_ENV=NtlmAuthentication). Runtime adds a 'Startup' prefix to this and
@@ -26,7 +26,7 @@ namespace MusicStore
/// 1. Set the environment variable named SET ASPNET_ENV=NtlmAuthentication
/// 2. For selfhost based servers pass in a command line variable named --env with this value. Eg:
/// "commands": {
- /// "web": "Microsoft.AspNet.Hosting --server Microsoft.AspNet.Server.WebListener
+ /// "web": "Microsoft.AspNetCore.Hosting --server Microsoft.AspNetCore.Server.WebListener
/// --server.urls http://localhost:5002 --ASPNET_ENV NtlmAuthentication",
/// },
///
@@ -15,7 +15,7 @@ namespace MusicStore
///
/// To make runtime to load an environment based startup class, specify the environment by the following ways:
- /// 1. Drop a Microsoft.AspNet.Hosting.ini file in the wwwroot folder
+ /// 1. Drop a Microsoft.AspNetCore.Hosting.ini file in the wwwroot folder
/// 2. Add a setting in the ini file named 'ASPNET_ENV' with value of the format 'Startup[EnvironmentName]'.
/// For example: To load a Startup class named 'StartupNtlmAuthentication' the value of the env should be
diff --git a/src/MusicStore/StartupOpenIdConnect.cs b/src/MusicStore/StartupOpenIdConnect.cs
index 211894403a..2b818e7576 100644
--- a/src/MusicStore/StartupOpenIdConnect.cs
+++ b/src/MusicStore/StartupOpenIdConnect.cs
@@ -1,6 +1,6 @@
-using Microsoft.AspNet.Builder;
-using Microsoft.AspNet.Identity.EntityFramework;
-using Microsoft.Data.Entity;
+using Microsoft.AspNetCore.Builder;
+using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
+using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
@@ -12,7 +12,7 @@ namespace MusicStore
{
///
/// To make runtime to load an environment based startup class, specify the environment by the following ways:
/// 1. Drop a Microsoft.AspNet.Hosting.ini file in the wwwroot folder
/// 2. Add a setting in the ini file named 'ASPNET_ENV' with value of the format 'Startup[EnvironmentName]'.
/// For example: To load a Startup class named 'StartupOpenIdConnect' the value of the env should be
/// 'OpenIdConnect' (eg. ASPNET_ENV=OpenIdConnect). Runtime adds a 'Startup' prefix to this
@@ -23,7 +23,7 @@ namespace MusicStore
/// 1. Set the environment variable named SET ASPNET_ENV=OpenIdConnect
/// 2. For selfhost based servers pass in a command line variable named --env with this value. Eg:
/// "commands": {
- /// "web": "Microsoft.AspNet.Hosting --server Microsoft.AspNet.Server.WebListener
+ /// "web": "Microsoft.AspNetCore.Hosting --server Microsoft.AspNetCore.Server.WebListener
/// --server.urls http://localhost:5002 --ASPNET_ENV OpenIdConnect",
/// },
///
@@ -12,7 +12,7 @@ namespace MusicStore
///
/// To make runtime to load an environment based startup class, specify the environment by the following ways:
- /// 1. Drop a Microsoft.AspNet.Hosting.ini file in the wwwroot folder
+ /// 1. Drop a Microsoft.AspNetCore.Hosting.ini file in the wwwroot folder
/// 2. Add a setting in the ini file named 'ASPNET_ENV' with value of the format 'Startup[EnvironmentName]'.
/// For example: To load a Startup class named 'StartupOpenIdConnect' the value of the env should be